@@ -7,40 +7,32 @@ try:
 except ImportError:  # SQLA < 0.9  # pragma: no cover
     from sqlalchemy.sql import expression as functions
     from sqlalchemy.sql.expression import FunctionElement
-from sqlalchemy.types import to_instance
+
 from sqlalchemy.ext.compiler import compiles
+from sqlalchemy.types import to_instance
 
 from .exc import ArgumentError
 
-
 BinasciiError = binascii.Error
 
 function_registry = set()
 
 
 class HasFunction(object):
+    """Base class used as a marker to know if a given element has a 'geom_from' function."""
     pass
 
 
 class _SpatialElement(HasFunction):
-    """
-    The base class for :class:`geoalchemy2.elements.WKTElement` and
-    :class:`geoalchemy2.elements.WKBElement`.
+    """The base class for public spatial elements.
 
-    The first argument passed to the constructor is the data wrapped
-    by the ``_SpatialElement` object being constructed.
-
-    Additional arguments:
-
-    ``srid``
-
-        An integer representing the spatial reference system. E.g. 4326.
-        Default value is -1, which means no/unknown reference system.
-
-    ``extended``
-
-        A boolean indicating whether the extended format (EWKT or EWKB)
-        is used. Default is ``False``.
+    Args:
+        data: The first argument passed to the constructor is the data wrapped
+            by the ``_SpatialElement`` object being constructed.
+        srid: An integer representing the spatial reference system. E.g. ``4326``.
+            Default value is ``-1``, which means no/unknown reference system.
+        extended: A boolean indicating whether the extended format (EWKT or EWKB)
+            is used. Default is ``False``.
 
     """
 
@@ -81,7 +73,7 @@ class _SpatialElement(HasFunction):
         #
 
         # Raise an AttributeError when the attribute name doesn't start
-        # with st_. This is to be nice with other librairies that use
+        # with st_. This is to be nice with other libraries that use
         # some ducktyping (e.g. hasattr(element, "copy")) to determine
         # the type of the element.
 
@@ -202,8 +194,8 @@ class WKBElement(_SpatialElement):
         """
         if isinstance(self.data, str):
             # SpatiaLite case
-            return self.data
-        desc = str(binascii.hexlify(self.data), encoding="utf-8")
+            return self.data.lower()
+        desc = str(binascii.hexlify(self.data), encoding="utf-8").lower()
         return desc
 
     @staticmethod
@@ -249,11 +241,10 @@ class RasterElement(_SpatialElement):
 
 
 class CompositeElement(FunctionElement):
-    """
-    Instances of this class wrap a Postgres composite type.
-    """
+    """Instances of this class wrap a Postgres composite type."""
 
     inherit_cache = False
+    """The cache is disabled for this class."""
 
     def __init__(self, base, field, type_):
         self.name = field
