@@ -8,10 +8,13 @@ Reference
 """
 import warnings
 
-from sqlalchemy.types import UserDefinedType, Integer, Float
-from sqlalchemy.sql import func
 from sqlalchemy.dialects import postgresql
-from sqlalchemy.dialects.postgresql.base import ischema_names
+from sqlalchemy.dialects.postgresql.base import ischema_names as postgresql_ischema_names
+from sqlalchemy.dialects.sqlite.base import ischema_names as sqlite_ischema_names
+from sqlalchemy.sql import func
+from sqlalchemy.types import Float
+from sqlalchemy.types import Integer
+from sqlalchemy.types import UserDefinedType
 
 try:
     from .shape import to_shape
@@ -20,8 +23,12 @@ except ImportError:
     SHAPELY = False
 
 
-from .comparator import BaseComparator, Comparator
-from .elements import WKBElement, WKTElement, RasterElement, CompositeElement
+from .comparator import BaseComparator
+from .comparator import Comparator
+from .elements import CompositeElement
+from .elements import RasterElement
+from .elements import WKBElement
+from .elements import WKTElement
 from .exc import ArgumentError
 
 
@@ -40,79 +47,61 @@ class _GISType(UserDefinedType):
     objects. The function returned by ``bind_processor`` converts
     :class:`geoalchemy2.elements.WKTElement` objects to EWKT strings.
 
-    Constructor arguments:
+    Args:
+        geometry_type: The geometry type.
 
-    ``geometry_type``
+            Possible values are:
 
-        The geometry type.
+              * ``"GEOMETRY"``,
+              * ``"POINT"``,
+              * ``"LINESTRING"``,
+              * ``"POLYGON"``,
+              * ``"MULTIPOINT"``,
+              * ``"MULTILINESTRING"``,
+              * ``"MULTIPOLYGON"``,
+              * ``"GEOMETRYCOLLECTION"``,
+              * ``"CURVE"``,
+              * ``None``.
 
-        Possible values are:
+           The latter is actually not supported with
+           :class:`geoalchemy2.types.Geography`.
 
-          * ``"GEOMETRY"``,
-          * ``"POINT"``,
-          * ``"LINESTRING"``,
-          * ``"POLYGON"``,
-          * ``"MULTIPOINT"``,
-          * ``"MULTILINESTRING"``,
-          * ``"MULTIPOLYGON"``,
-          * ``"GEOMETRYCOLLECTION"``,
-          * ``"CURVE"``,
-          * ``None``.
+           When set to ``None`` then no "geometry type" constraints will be
+           attached to the geometry type declaration. Using ``None`` here
+           is not compatible with setting ``management`` to ``True``.
 
-       The latter is actually not supported with
-       :class:`geoalchemy2.types.Geography`.
+           Default is ``"GEOMETRY"``.
 
-       When set to ``None`` then no "geometry type" constraints will be
-       attached to the geometry type declaration. Using ``None`` here
-       is not compatible with setting ``management`` to ``True``.
+        srid: The SRID for this column. E.g. 4326. Default is ``-1``.
+        dimension: The dimension of the geometry. Default is ``2``.
 
-       Default is ``"GEOMETRY"``.
+            With ``management`` set to ``True``, that is when ``AddGeometryColumn`` is used
+            to add the geometry column, there are two constraints:
 
-    ``srid``
+            * The ``geometry_type`` must not end with ``"ZM"``.  This is due to PostGIS'
+              ``AddGeometryColumn`` failing with ZM geometry types. Instead the "simple"
+              geometry type (e.g. POINT rather POINTZM) should be used with ``dimension``
+              set to ``4``.
+            * When the ``geometry_type`` ends with ``"Z"`` or ``"M"`` then ``dimension``
+              must be set to ``3``.
 
-        The SRID for this column. E.g. 4326. Default is ``-1``.
+            With ``management`` set to ``False`` (the default) ``dimension`` is not
+            taken into account, and the actual dimension is fully defined with the
+            ``geometry_type``.
 
-    ``dimension``
-
-        The dimension of the geometry. Default is ``2``.
-
-        With ``management`` set to ``True``, that is when ``AddGeometryColumn`` is used
-        to add the geometry column, there are two constraints:
-
-        * The ``geometry_type`` must not end with ``"ZM"``.  This is due to PostGIS'
-          ``AddGeometryColumn`` failing with ZM geometry types. Instead the "simple"
-          geometry type (e.g. POINT rather POINTZM) should be used with ``dimension``
-          set to ``4``.
-        * When the ``geometry_type`` ends with ``"Z"`` or ``"M"`` then ``dimension``
-          must be set to ``3``.
-
-        With ``management`` set to ``False`` (the default) ``dimension`` is not
-        taken into account, and the actual dimension is fully defined with the
-        ``geometry_type``.
-
-    ``spatial_index``
-
-        Indicate if a spatial index should be created. Default is ``True``.
-
-    ``use_N_D_index``
-        Use the N-D index instead of the standard 2-D index.
-
-    ``management``
-
-        Indicate if the ``AddGeometryColumn`` and ``DropGeometryColumn``
-        managements functions should be called when adding and dropping the
-        geometry column. Should be set to ``True`` for PostGIS 1.x. Default is
-        ``False``. Note that this option has no effect for
-        :class:`geoalchemy2.types.Geography`.
-
-    ``use_typmod``
-
-        By default PostgreSQL type modifiers are used to create the geometry
-        column. To use check constraints instead set ``use_typmod`` to
-        ``False``. By default this option is not included in the call to
-        ``AddGeometryColumn``. Note that this option is only taken
-        into account if ``management`` is set to ``True`` and is only available
-        for PostGIS 2.x.
+        spatial_index: Indicate if a spatial index should be created. Default is ``True``.
+        use_N_D_index: Use the N-D index instead of the standard 2-D index.
+        management: Indicate if the ``AddGeometryColumn`` and ``DropGeometryColumn``
+            managements functions should be called when adding and dropping the
+            geometry column. Should be set to ``True`` for PostGIS 1.x and SQLite. Default is
+            ``False``. Note that this option has no effect for
+            :class:`geoalchemy2.types.Geography`.
+        use_typmod: By default PostgreSQL type modifiers are used to create the geometry
+            column. To use check constraints instead set ``use_typmod`` to
+            ``False``. By default this option is not included in the call to
+            ``AddGeometryColumn``. Note that this option is only taken
+            into account if ``management`` is set to ``True`` and is only available
+            for PostGIS 2.x.
     """
 
     name = None
@@ -136,7 +125,7 @@ class _GISType(UserDefinedType):
 
     def __init__(self, geometry_type='GEOMETRY', srid=-1, dimension=2,
                  spatial_index=True, use_N_D_index=False, management=False, use_typmod=None,
-                 from_text=None, name=None, nullable=True):
+                 from_text=None, name=None, nullable=True, _spatial_index_reflected=None):
         geometry_type, srid = self.check_ctor_args(
             geometry_type, srid, dimension, management, use_typmod, nullable)
         self.geometry_type = geometry_type
@@ -152,6 +141,7 @@ class _GISType(UserDefinedType):
         self.use_typmod = use_typmod
         self.extended = self.as_binary == 'ST_AsEWKB'
         self.nullable = nullable
+        self._spatial_index_reflected = _spatial_index_reflected
 
     def get_col_spec(self):
         if not self.geometry_type:
@@ -163,6 +153,7 @@ class _GISType(UserDefinedType):
         return getattr(func, self.as_binary)(col, type_=self)
 
     def result_processor(self, dialect, coltype):
+        """Specific result_processor that automatically process spatial elements"""
         def process(value):
             if value is not None:
                 kwargs = {}
@@ -178,6 +169,7 @@ class _GISType(UserDefinedType):
         return getattr(func, self.from_text)(bindvalue, type_=self)
 
     def bind_processor(self, dialect):
+        """Specific bind_processor that automatically process spatial elements"""
         def process(bindvalue):
             if isinstance(bindvalue, WKTElement):
                 if bindvalue.extended:
@@ -324,11 +316,8 @@ class Raster(_GISType):
     received from the database are converted to
     :class:`geoalchemy2.elements.RasterElement` objects.
 
-    Constructor arguments:
-
-    ``spatial_index``
-
-        Indicate if a spatial index should be created. Default is ``True``.
+    Args:
+        spatial_index: Indicate if a spatial index should be created. Default is ``True``.
 
     """
 
@@ -356,14 +345,30 @@ class Raster(_GISType):
     cache_ok = False
     """ Disable cache for this type. """
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, spatial_index=True, from_text=None, name=None, nullable=True):
         # Enforce default values
-        kwargs['geometry_type'] = None
-        kwargs['srid'] = -1
-        super(Raster, self).__init__(*args, **kwargs)
+        super(Raster, self).__init__(
+            geometry_type=None,
+            srid=-1,
+            dimension=2,
+            spatial_index=spatial_index,
+            use_N_D_index=False,
+            management=False,
+            use_typmod=False,
+            from_text=from_text,
+            name=name,
+            nullable=nullable,
+        )
         self.extended = None
 
 
+class _DummyGeometry(Geometry):
+    """A dummy type only used with SQLite."""
+
+    def get_col_spec(self):
+        return 'GEOMETRY'
+
+
 class CompositeType(UserDefinedType):
     """
     A wrapper for :class:`geoalchemy2.elements.CompositeElement`, that can be
@@ -401,11 +406,21 @@ class GeometryDump(CompositeType):
     """ Enable cache for this type. """
 
 
-# Register Geometry, Geography and Raster to SQLAlchemy's Postgres reflection
-# subsystem.
-ischema_names['geometry'] = Geometry
-ischema_names['geography'] = Geography
-ischema_names['raster'] = Raster
+# Register Geometry, Geography and Raster to SQLAlchemy's reflection subsystems.
+postgresql_ischema_names['geometry'] = Geometry
+postgresql_ischema_names['geography'] = Geography
+postgresql_ischema_names['raster'] = Raster
+
+sqlite_ischema_names['GEOMETRY'] = Geometry
+sqlite_ischema_names['POINT'] = Geometry
+sqlite_ischema_names['LINESTRING'] = Geometry
+sqlite_ischema_names['POLYGON'] = Geometry
+sqlite_ischema_names['MULTIPOINT'] = Geometry
+sqlite_ischema_names['MULTILINESTRING'] = Geometry
+sqlite_ischema_names['MULTIPOLYGON'] = Geometry
+sqlite_ischema_names['CURVE'] = Geometry
+sqlite_ischema_names['GEOMETRYCOLLECTION'] = Geometry
+sqlite_ischema_names['RASTER'] = Raster
 
 
 class SummaryStats(CompositeType):
